if [ -z ${CONDA_BUILD+x} ]; then
    source /opt/concourse/worker/volumes/live/aea70147-2fc8-4843-7392-2ca50fc9d5a7/volume/pymongo_1607369031194/work/build_env_setup.sh
fi
python setup.py install --single-version-externally-managed --record=record.txt